@@ -30,7 +30,21 @@ def ansible_playbook(
     send_command: bool,
     forks: int,
 ) -> None:
-    """Use approved creds for RESOURCE to run an Ansible command."""
+    """Run Ansible commands against an inventory of EC2 instances, using
+    approved credentials from the Sym RESOURCE group.
+
+    For a list of available Sym RESOURCES, run `sym resources`.
+
+    \b
+    Example:
+        `sym ansible-playbook RESOURCE -i path/to/inventory.txt path/to/playbook.yml`
+
+    Extra arguments can be passed by adding them to the end of the command.
+
+    \b
+    Example:
+        `sym ansible-playbook RESOURCE -i path/to/inventory.txt path/to/playbook.yml -vvvv -some -other -options`
+    """
     client = options.create_saml_client(resource)
     run_ansible(
         client,
