@@ -103,7 +103,9 @@ class InstanceNotFound(CliError):
 
 class SAMLClientNotFound(CliError):
     def __init__(self) -> None:
-        super().__init__("No valid SAML client found in PATH")
+        super().__init__(
+            "No valid SAML client found in PATH. Supported clients are listed in `sym --help`."
+        )
 
 
 class OfflineError(CliError):
