@@ -122,7 +122,13 @@ def get_ansible_env(
 
 def get_send_command_args(client: SAMLClient):
     bucket_name = get_ansible_bucket_name(client)
-    sym_host_to_instance_cmd = sym_subcommand(client, "host-to-instance", "$HOST")
+    client.dprint(f"Using bucket s3://{bucket_name}")
+
+    sym_host_to_instance_cmd = sym_subcommand(
+        client,
+        "host-to-instance",
+        "$HOST --json",
+    )
     extra_vars = {
         "ansible_aws_ssm_bucket": bucket_name,
         "ansible_aws_ssm_host_cmd": sym_host_to_instance_cmd,
