@@ -11,6 +11,8 @@ from typing import List, Sequence, Tuple
 
 import click
 
+from sym.cli.helpers.contexts import push_env
+
 from ..decorators import intercept_errors, retry, run_subprocess
 from ..errors import (
     AccessDenied,
@@ -106,17 +108,19 @@ def ssh_args(client, instance, port) -> tuple:
 
 @run_subprocess
 def _start_background_ssh_session(client: SAMLClient, instance: str, port: int, *command):
-    yield (
-        *ssh_args(client, instance, port),
-        {"f": True},
-        "-o BatchMode=yes",
-        *command,
-    )
+    with push_env("SHELL", "/bin/bash"):
+        yield (
+            *ssh_args(client, instance, port),
+            {"f": True},
+            "-o BatchMode=yes",
+            *command,
+        )
 
 
 @run_subprocess
 def _start_ssh_session(client: SAMLClient, instance: str, port: int, *command: str):
-    yield (*ssh_args(client, instance, port), *command)
+    with push_env("SHELL", "/bin/bash"):
+        yield (*ssh_args(client, instance, port), *command)
 
 
 @intercept_errors(suppress=True)
@@ -205,16 +209,8 @@ def start_ssh_session(
         Config.touch_instance(instance)
 
 
-@retry(TargetNotConnected, delay=1, count=2)
-@intercept_errors({TargetNotConnectedPattern: TargetNotConnected}, suppress=True)
-def ensure_ssh_key(
-    client,
-    instance: str,
-    port: int,
-    *,
-    ttl: timedelta = timedelta(days=1),
-    args: Sequence[str] = [],
-):
+def gen_local_ssh_config(client) -> SymConfigFile:
+    client.dprint("writing SSH key")
     ssh_key, ssh_config = ssh_key_and_config(client)
     sym_cmd = f"PYTHONUNBUFFERED=1 sym {client.cli_options} ssh-session {client.resource} --instance %h --port %p"
 
@@ -239,20 +235,21 @@ def ensure_ssh_key(
             PasswordAuthentication no
             ChallengeResponseAuthentication no
             GSSAPIAuthentication no
-            ProxyCommand sh -c "{sym_cmd} || exit $?"
+            ProxyCommand sh -c "{sym_cmd} || exit \$?"
             {mux_config.strip()}
         """
     ))
     # fmt: on
+    return ssh_config
 
-    client.dprint("writing SSH key")
-
-    maybe_gen_ssh_key(client)
-
-    if Config.check_instance_ttl(instance, ttl):
-        client.dprint(f"Skipping remote SSH key check for {instance}")
-        return
 
+def ensure_public_key_on_instance(
+    client,
+    instance: str,
+    port: int,
+    *,
+    args: Sequence[str] = [],
+):
     try:
         _start_background_ssh_session(
             client, instance, port, *args, "exit", capture_output_=True
@@ -261,12 +258,33 @@ def ensure_ssh_key(
         client.dprint(f"SSH Check Error: {err.stdout}")
         if not MissingPublicKeyPattern.search(err.stderr):
             raise
+        ssh_key, _ = ssh_key_and_config(client)
         send_ssh_key(client, instance, ssh_key)
     else:
         client.dprint("remote SSH key check succeeded")
         Config.touch_instance(instance)
 
 
+@retry(TargetNotConnected, delay=1, count=2)
+@intercept_errors({TargetNotConnectedPattern: TargetNotConnected}, suppress=True)
+def ensure_ssh_key(
+    client,
+    instance: str,
+    port: int,
+    *,
+    ttl: timedelta = timedelta(days=1),
+    args: Sequence[str] = [],
+):
+    gen_local_ssh_config(client)
+    maybe_gen_ssh_key(client)
+
+    if Config.check_instance_ttl(instance, ttl):
+        client.dprint(f"Skipping remote SSH key check for {instance}")
+        return
+
+    ensure_public_key_on_instance(client, instance, port, args=args)
+
+
 def start_tunnel(client, instance: str, port: int):
     SymGroup.reset_tees()
     client.dprint("execing aws ssm")
