@@ -11,9 +11,11 @@ from botocore.stub import Stubber
 from click.testing import CliRunner
 
 from sym.cli.helpers import boto
+from sym.cli.helpers import os as sym_os
 from sym.cli.helpers.config import Config
 from sym.cli.helpers.envvar_option import reset_used
 from sym.cli.helpers.global_options import GlobalOptions
+from sym.cli.helpers.sym_group import SymGroup
 from sym.cli.saml_clients.aws_okta import AwsOkta
 from sym.cli.saml_clients.aws_profile import AwsProfile
 from sym.cli.saml_clients.saml_client import SAMLClient
@@ -29,6 +31,11 @@ def patch_is_setup(monkeypatch: MonkeyPatch):
     monkeypatch.setattr(SAMLClient, "check_is_setup", lambda self: ...)
 
 
+@pytest.fixture(autouse=True)
+def patch_execvp(monkeypatch: MonkeyPatch):
+    monkeypatch.setattr(sym_os, "execvp", lambda client, args: client.exec(*args))
+
+
 @pytest.fixture
 def sandbox(tmp_path: Path) -> Sandbox:
     return Sandbox(tmp_path)
@@ -181,3 +188,8 @@ def setup_context():
 
 def empty_saml_client():
     return AwsProfile("test", options=GlobalOptions())
+
+
+@pytest.fixture(autouse=True)
+def cleanup(request):
+    request.addfinalizer(SymGroup.reset_tees)
