@@ -1,3 +1,4 @@
+import random
 from contextlib import contextmanager
 
 import pytest
@@ -7,6 +8,19 @@ from expects import *
 from sym.cli.sym import sym as click_command
 from sym.cli.tests.matchers import succeed
 
+INSTANCES = [
+    "i-052113589d5e8b832",
+    "i-06ee7489efaeb582e",
+    "i-0f3913172f1f4d1c0",
+    "i-0ca07db4abb01d098",
+    "i-0da5718079be3162c",
+    "i-03371cb517e30eb22",
+    "i-0e717dd52e0186713",
+    "i-03c087811b23a2a4f",
+    "i-08b3c84ebd6645df6",
+    "i-0f5d63478e7cb781b",
+]
+
 
 @pytest.fixture
 def integration_runner(capfdbinary, sandbox):
@@ -32,5 +46,5 @@ def integration_runner(capfdbinary, sandbox):
 def pytest_addoption(parser):
     parser.addoption("--email", default="ci@symops.io")
     parser.addoption("--org", default="sym")
-    parser.addoption("--instance", default="i-06d0713fa5088af8a")
+    parser.addoption("--instance", default=random.choice(INSTANCES))
     parser.addoption("--resource", default="test")
